Enumeration: UpdateModeEnum | Chart.js
Description: Open source HTML5 Charts for your website

# # Enumeration: UpdateModeEnum

## # Enumeration members

### # active

• active = `"active"`

#### # Defined in

index.esm.d.ts:568
(opens new window)

### # hide

• hide = `"hide"`

#### # Defined in

index.esm.d.ts:565
(opens new window)

### # none

• none = `"none"`

#### # Defined in

index.esm.d.ts:564
(opens new window)

### # normal

• normal = `"normal"`

#### # Defined in

index.esm.d.ts:567
(opens new window)

### # reset

• reset = `"reset"`

#### # Defined in

index.esm.d.ts:563
(opens new window)

### # resize

• resize = `"resize"`

#### # Defined in

index.esm.d.ts:562
(opens new window)

### # show

• show = `"show"`

#### # Defined in

index.esm.d.ts:566
(opens new window)